@@ -105,8 +105,8 @@ async def get_languages() -> Dict[Text, Any]:
             )
             console.print(f"{json.dumps(json_response, indent=4)}")
         else:
-            logger.error("> [red]ERROR[/red] ❌ Failed to create project")
-            logger.error(
+            console.print("> [red]ERROR[/red] ❌ Failed to create project")
+            console.print(
                 f"😔 Platform response: \n{json.dumps(json_response, indent=4)}"
             )
     return json_response
@@ -185,8 +185,8 @@ async def delete_project(project_id: Text) -> Dict[Text, Any]:
                 "> [deep_sky_blue2]INFO[/deep_sky_blue2] ✅ Successfully deleted project"
             )
         else:
-            logger.error("> [red]ERROR[/red] ❌ Failed to delete projects")
-            logger.error(
+            console.print("> [red]ERROR[/red] ❌ Failed to delete projects")
+            console.print(
                 f"😔 Platform response: \n{json.dumps(json_response, indent=4)}"
             )
     return json_response
@@ -401,8 +401,8 @@ async def list_models(
         if is_success_status(response.status):
             print_models_table(json_response, verbose)
         else:
-            logger.error("> [red]ERROR[/red] ❌ Failed to list models")
-            logger.error(
+            console.print("> [red]ERROR[/red] ❌ Failed to list models")
+            console.print(
                 f"> Platform response: \n{json.dumps(json_response, indent=4)}"
             )
     return json_response
@@ -426,8 +426,8 @@ async def delete_examples(example_ids: List[Text]) -> Dict[Text, Any]:
                 "> [deep_sky_blue2]INFO[/deep_sky_blue2] ✅ Successfully deleted example!"
             )
         else:
-            logger.error("> [red]ERROR[/red] ❌ Failed to delete examples")
-            logger.error(
+            console.print("> [red]ERROR[/red] ❌ Failed to delete examples")
+            console.print(
                 f"> Platform response: \n{json.dumps(json_response, indent=4)}"
             )
     return json_response
